@@ -9,6 +9,7 @@
 #include "StaticAccessedThroughInstanceCheck.h"
 #include "clang/AST/ASTContext.h"
 #include "clang/ASTMatchers/ASTMatchFinder.h"
+#include "llvm/ADT/StringRef.h"
 
 using namespace clang::ast_matchers;
 
@@ -18,14 +19,15 @@ namespace readability {
 
 static unsigned getNameSpecifierNestingLevel(const QualType &QType) {
   if (const ElaboratedType *ElType = QType->getAs<ElaboratedType>()) {
-    const NestedNameSpecifier *NestedSpecifiers = ElType->getQualifier();
-    unsigned NameSpecifierNestingLevel = 1;
-    do {
-      NameSpecifierNestingLevel++;
-      NestedSpecifiers = NestedSpecifiers->getPrefix();
-    } while (NestedSpecifiers);
+    if (const NestedNameSpecifier *NestedSpecifiers = ElType->getQualifier()) {
+      unsigned NameSpecifierNestingLevel = 1;
+      do {
+        NameSpecifierNestingLevel++;
+        NestedSpecifiers = NestedSpecifiers->getPrefix();
+      } while (NestedSpecifiers);
 
-    return NameSpecifierNestingLevel;
+      return NameSpecifierNestingLevel;
+    }
   }
   return 0;
 }
@@ -54,7 +56,7 @@ void StaticAccessedThroughInstanceCheck::check(
 
   const Expr *BaseExpr = MemberExpression->getBase();
 
-  // Do not warn for overlaoded -> operators.
+  // Do not warn for overloaded -> operators.
   if (isa<CXXOperatorCallExpr>(BaseExpr))
     return;
 
@@ -67,9 +69,17 @@ void StaticAccessedThroughInstanceCheck::check(
   PrintingPolicy PrintingPolicyWithSupressedTag(AstContext->getLangOpts());
   PrintingPolicyWithSupressedTag.SuppressTagKeyword = true;
   PrintingPolicyWithSupressedTag.SuppressUnwrittenScope = true;
+
+  PrintingPolicyWithSupressedTag.PrintCanonicalTypes =
+      !BaseExpr->getType()->isTypedefNameType();
+
   std::string BaseTypeName =
       BaseType.getAsString(PrintingPolicyWithSupressedTag);
 
+  // Do not warn for CUDA built-in variables.
+  if (StringRef(BaseTypeName).startswith("__cuda_builtin_"))
+    return;
+
   SourceLocation MemberExprStartLoc = MemberExpression->getBeginLoc();
   auto Diag =
       diag(MemberExprStartLoc, "static member accessed through instance");
